package info.textgrid.middleware;

import java.io.IOException;
import org.elasticsearch.action.get.GetRequest;
import org.elasticsearch.action.get.GetResponse;
import org.elasticsearch.client.RequestOptions;
import org.elasticsearch.common.Strings;
import org.elasticsearch.search.fetch.subphase.FetchSourceContext;
import info.textgrid.middleware.oaipmh.ListMetadataFormatsType;
import info.textgrid.middleware.oaipmh.MetadataFormatType;

/**
 *
 */
public class MetadataFormatListDelivererTG extends MetadataFormatListDelivererAbstract {

  // **
  // FINALS
  // **

  public static final String URI = "textgridUri";

  /**
   * 
   */
  public MetadataFormatListDelivererTG() {
    //
  }

  /**
   * <p>
   * Get metadata format list for specific ID.
   * </p>
   */
  @Override
  public ListMetadataFormatsType setMetadataFormatList(String id) {

    String[] includes = new String[] {URI};
    String[] excludes = Strings.EMPTY_ARRAY;
    FetchSourceContext fetchSourceContext = new FetchSourceContext(true, includes, excludes);

    ListMetadataFormatsType lmft = new ListMetadataFormatsType();
    MetadataFormatType mft = new MetadataFormatType();
    MetadataFormatType openAireMetadataFormat = new MetadataFormatType();

    GetRequest getRequest =
        new GetRequest(this.oaiEsClient.getEsIndex(), this.oaiEsClient.getEsType(),
            id.replace("textgrid:", "")).fetchSourceContext(fetchSourceContext);

    GetResponse tgObject = null;
    try {
      tgObject = this.oaiEsClient.getEsClient().get(getRequest, RequestOptions.DEFAULT);

      if (tgObject.isExists()) {
        setIdExist(true);
        mft.setMetadataPrefix(OaipmhConstants.METADATA_OAIDC_PREFIX);
        mft.setMetadataNamespace(OaipmhConstants.OAIDC_NAMESPACE);
        mft.setSchema(OaipmhConstants.OAIDC_SCHEMA_LOCATION);

        openAireMetadataFormat.setMetadataPrefix(OaipmhConstants.METADATA_OPENAIRE_PREFIX);
        openAireMetadataFormat.setMetadataNamespace(OaipmhConstants.DATACITE_NAMESPACE);
        openAireMetadataFormat.setSchema(OaipmhConstants.DATACITE_SCHEMA_LOCATION);

        lmft.getMetadataFormat().add(mft);
        lmft.getMetadataFormat().add(openAireMetadataFormat);

      } else {
        setIdExist(false);
        lmft = null;
      }
    } catch (IOException e) {
      // TODO Auto-generated catch block
      e.printStackTrace();
    }

    return lmft;
  }

  /**
   *
   */
  @Override
  public ListMetadataFormatsType setMetadataFormatList() {

    // Get things from abstract class.
    ListMetadataFormatsType result = super.setMetadataFormatList();

    // Add metadata format for IDIOM METS.
    MetadataFormatType mftIdiomMets = new MetadataFormatType();
    mftIdiomMets.setMetadataPrefix(OaipmhConstants.METADATA_IDIOM_PREFIX);
    mftIdiomMets.setMetadataNamespace(OaipmhConstants.METS_NAMESPACE);
    mftIdiomMets.setSchema(OaipmhConstants.METS_SCHEMA_LOCATION);

    result.getMetadataFormat().add(mftIdiomMets);

    return result;
  }

}
