package info.textgrid.middleware;

import java.io.IOException;
import java.text.ParseException;
import java.util.logging.Logger;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;
import javax.ws.rs.core.MediaType;
import org.apache.cxf.jaxrs.client.JAXRSClientFactory;

/**
 *
 */
public class OaipmhClient {

  private static Logger log = Logger.getLogger(OaipmhClient.class.getName());

  private String identifier;
  private String metadataPrefix;
  private String set;
  private String from;
  private String until;
  private String resumptionToken;
  private OaipmhProducer producer;

  /**
   * @param endpoint
   */
  public OaipmhClient(String endpoint) {

    log.fine("  ##  START CREATING PRODUCER");

    this.producer = JAXRSClientFactory.create(endpoint + "/oai", OaipmhProducer.class);

    log.fine("  ##  END CREATING PRODUCER");
  }

  /**
   * @param verb
   * @return
   * @throws ParseException
   * @throws IOException
   */
  public String request(String verb) throws ParseException, IOException {

    log.fine("  ##  START request");

    String result =
        this.producer.getRequest(verb, this.identifier, this.metadataPrefix, this.set, this.from,
            this.until, this.resumptionToken);

    log.fine("  ##  END request");

    return result;
  }

  /**
   * @return
   */
  @GET
  @Path("/version")
  @Produces(MediaType.TEXT_PLAIN)
  public String getVersion() {
    return OaipmhServiceVersion.BUILDNAME + "-" + OaipmhServiceVersion.VERSION + "+"
        + OaipmhServiceVersion.BUILDDATE;
  }

}
